@@ -37,7 +37,6 @@ logger = logging.getLogger(__name__)
 class BaseXenForo2ForumAdapter(BaseXenForoForumAdapter):
 
     def __init__(self, config, url):
-        logger.info("init url: "+url)
         BaseXenForoForumAdapter.__init__(self, config, url)
 
     @classmethod
@@ -45,9 +44,14 @@ class BaseXenForo2ForumAdapter(BaseXenForoForumAdapter):
         "Only needs to be overriden if has additional ini sections."
         return super(BaseXenForo2ForumAdapter, cls).getConfigSections() + ['base_xenforo2forum']
 
-    def performLogin(self):
+    def performLogin(self,data):
         params = {}
 
+        if data and "Log in" not in data:
+            ## already logged in.
+            logger.debug("Already Logged In")
+            return
+
         if self.password:
             params['login'] = self.username
             params['password'] = self.password
@@ -77,7 +81,7 @@ class BaseXenForo2ForumAdapter(BaseXenForoForumAdapter):
         d = self._postUrl(loginUrl, params)# , headers={ 'referer':self.getURLPrefix() + '/login',
                                            #            'origin':self.getURLPrefix() })
 
-        if "Log In" in d:
+        if "Log in" in d:
             # logger.debug(d)
             logger.info("Failed to login to URL %s as %s" % (self.url,
                                                              params['login']))
@@ -98,6 +102,44 @@ class BaseXenForo2ForumAdapter(BaseXenForoForumAdapter):
         self.story.setMetadata('title',stripHTML(h1))
         # logger.debug(stripHTML(h1))
 
+    def set_threadmarks_metadata(self,useurl,topsoup):
+        header = topsoup.find('div',{'class':'threadmarkListingHeader'})
+        if header:
+            # logger.debug(header)
+            desc = self.get_post_body(header)
+            if desc:
+                self.story.setMetadata("threadmarks_description",desc)
+                if self.getConfig('use_threadmarks_description'):
+                    self.setDescription(useurl,desc)
+            # logger.debug(desc)
+            title = header.find('h1',{'class':'threadmarkListingHeader-name'})
+            if title:
+                self.story.setMetadata("threadmarks_title",stripHTML(title))
+            statusdt = header.find('dt',text="Index progress")
+            if statusdt:
+                statusdd = statusdt.find_next_sibling('dd')
+                if statusdd:
+                    threadmarks_status = stripHTML(statusdd)
+                    self.story.setMetadata("threadmarks_status",threadmarks_status)
+                    if self.getConfig('use_threadmarks_status'):
+                        if 'Complete' in threadmarks_status:
+                            self.story.setMetadata('status','Completed')
+                        elif 'Incomplete' in threadmarks_status:
+                            self.story.setMetadata('status','In-Progress')
+                        else:
+                            self.story.setMetadata('status',threadmarks_status)
+            if self.getConfig('use_threadmarks_cover'):
+                cover = header.find('span',{'class':'threadmarkListingHeader-icon'})
+                # logger.debug(cover)
+                if cover:
+                    img = cover.find('img')
+                    if img:
+                        src = img['src']
+                        if img.has_attr('srcset'):
+                            src = img['srcset']
+                        self.setCoverImage(useurl,src)
+        return
+
     def get_forumtags(self,topsoup):
         return topsoup.find('div',{'class':'p-description'}).findAll('a',{'class':'tagItem'})
 
@@ -105,7 +147,9 @@ class BaseXenForo2ForumAdapter(BaseXenForoForumAdapter):
         a = souptag.find('section',{'class':'message-user'}).find('a',{'class':'username'})
         # logger.debug(a)
         self.story.addToList('authorId',a['href'].split('/')[-2])
-        authorUrl = a['href'] # self.getURLPrefix()+'/'+a['href']
+        authorUrl = a['href']
+        if not authorUrl.startswith('http'):
+            authorUrl = self.getURLPrefix()+authorUrl
         self.story.addToList('authorUrl',authorUrl)
         self.story.addToList('author',a.text)
 
@@ -186,7 +230,7 @@ class BaseXenForo2ForumAdapter(BaseXenForoForumAdapter):
             # not paying any attention to TZ issues.
             return datetime.fromtimestamp(float(datetag['data-time']))
         except:
-            logger.warn('No date found in %s'%parenttag,exc_info=True)
+            # logger.warn('No date found in %s'%parenttag,exc_info=True)
             return None
 
     def make_reader_url(self,tmcat_num,reader_page_num):
@@ -204,3 +248,12 @@ class BaseXenForo2ForumAdapter(BaseXenForoForumAdapter):
         ## as XF1.
         for tag in soup.find_all('div', class_="bbCodeBlock-expandContent"):
             tag.name='blockquote'
+
+    def get_last_page_url(self,topsoup):
+        ## <ul class="pageNav-main">
+        ul = topsoup.find('ul',{'class':'pageNav-main'})
+        # logger.debug(ul)
+        lastpage = ul.find_all('a',href=re.compile(r'page-'))[-1]
+        # logger.debug(lastpage)
+        # doing make_soup will also cache posts from that last page.
+        return lastpage['href']
