@@ -24,7 +24,7 @@ from . import six
 from .six.moves import configparser
 from .six.moves.configparser import DEFAULTSECT, MissingSectionHeaderError, ParsingError
 from .six.moves import urllib
-from .six.moves.urllib.parse import urlencode
+from .six.moves.urllib.parse import (urlencode, quote_plus)
 from .six.moves.urllib.request import (build_opener, HTTPCookieProcessor, Request)
 from .six.moves.urllib.error import HTTPError
 from .six.moves import http_cookiejar as cl
@@ -1070,10 +1070,12 @@ class Configuration(configparser.SafeConfigParser):
         if 'Accept' not in headers:
             headers['Accept']="text/html,*/*"
 
-        if "xf2test" in url:
-            import base64
-            base64string = base64.encodestring(b"xf2demo2019:dBfbyHVvRCsYtLg846r3").replace(b'\n', b'')
-            headers['Authorization']=b"Basic %s" % base64string
+        # logger.debug("POST http login for SB xf2test %s"%url)
+        # if "xf2test" in url:
+        #     import base64
+        #     base64string = base64.encodestring(b"sbreview2019:Fs2PwuVE9").replace(b'\n', b'')
+        #     headers['Authorization']=b"Basic %s" % base64string
+        #     logger.debug("http login for SB xf2test")
 
         req = Request(url,
                       data=ensure_binary(urlencode(parameters)),
@@ -1111,6 +1113,9 @@ class Configuration(configparser.SafeConfigParser):
         sleeps.  Passed into fetchs so it can be bypassed when
         cache hits.
         '''
+
+        url = quote_plus(ensure_binary(url),safe=';/?:@&=+$,%&')
+
         if self.getConfig('force_https'): ## For developer testing only.
             url = url.replace("http:","https:")
         cachekey=self._get_cachekey(url, parameters)
@@ -1143,19 +1148,21 @@ class Configuration(configparser.SafeConfigParser):
             ## not present at all
             headers.append(('Referer',referer))
 
-        if "xf2test" in url:
-            import base64
-            base64string = base64.encodestring(b"xf2demo2019:dBfbyHVvRCsYtLg846r3").replace(b'\n', b'')
-            headers.append(('Authorization', b"Basic %s" % base64string))
+        # logger.debug("GET http login for SB xf2test %s"%url)
+        # if "xf2test" in url:
+        #     import base64
+        #     base64string = base64.encodestring(b"sbreview2019:Fs2PwuVE9").replace(b'\n', b'')
+        #     headers.append(('Authorization',b"Basic %s" % base64string))
+        #     logger.debug("http login for SB xf2test")
 
         self.opener.addheaders = headers
 
         if parameters != None:
-            opened = self.opener.open(url.replace(' ','%20'),
+            opened = self.opener.open(url,
                                       ensure_binary(urlencode(parameters)),
                                       float(self.getConfig('connect_timeout',30.0)))
         else:
-            opened = self.opener.open(url.replace(' ','%20'),
+            opened = self.opener.open(url,
                                       None,
                                       float(self.getConfig('connect_timeout',30.0)))
         self._progressbar()
